<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="112"/>
        <source>Install</source>
        <translation>Zainstaluj</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="91"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Zostaną zainstalowane następujące pakiety. Kliknij „Pokaż szczegóły...”, aby uzyskać informacje o pakietach.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="96"/>
        <source>File: %1</source>
        <translation>Plik: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="110"/>
        <source>Will install the following:</source>
        <translation>Zainstaluje następujące:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="123"/>
        <source>Installing selected package, please authenticate</source>
        <translation>Instalowanie wybranego pakietu, proszę uwierzytelnić</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="128"/>
        <source>Press any key to close</source>
        <translation>Naciśnij dowolny klawisz, aby zamknąć</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Program do instalacji pakietów binarnych Debiana (plików deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>pliki...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Nazwa plików .deb do zainstalowania</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[plik...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Wybierz pliki .deb do zainstalowania</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Pliki Deb (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Nie dostarczono żadnych plików .deb.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Nie znaleziono pliku %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Plik %1 nie jest plikiem .deb.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Musisz uruchomić ten program jako zwykły użytkownik.</translation>
    </message>
</context>
</TS>